"use strict";
Object.defineProperty(exports, Symbol.toStringTag, { value: "Module" });
const react = require("react");
const reactStore = require("@tanstack/react-store");
const lodashEs = require("lodash-es");
const utils = require("./utils.cjs");
const encoding = require("./encoding.cjs");
const useApi = require("./use-api.cjs");
const api = require("./api.cjs");
const createFancyParams = () => {
  let paramsStore = null;
  let api$1 = null;
  const getLatestParams = (api2) => {
    const params = new URLSearchParams(api2.getSearch());
    const paramsMap = {};
    for (const [key, value] of params) {
      paramsMap[key] = value;
    }
    return paramsMap;
  };
  const init = lodashEs.once((contextApi, isClient2) => {
    api$1 = api.withBatch(contextApi ?? api.defaultApi(utils.getRenderingType()));
    api$1.registerListener((state) => {
      if (utils.isFancyTransition(state)) {
        return;
      }
      paramsStore.setState(() => getLatestParams(api$1));
    });
    if (isClient2) {
      paramsStore = new reactStore.Store({});
      paramsStore.state = getLatestParams(api$1);
    }
  });
  const decodeWithDefault = (value, defaultValue, options) => {
    var _a, _b;
    try {
      if (value === void 0) {
        return defaultValue;
      }
      const decoded = encoding.decodeParam(value, options.decode);
      const isValid = options.validate ? options.validate(decoded) : true;
      if (!isValid) {
        (_a = options.onError) == null ? void 0 : _a.call(options, value);
        return defaultValue;
      }
      return decoded;
    } catch (_e) {
      (_b = options.onError) == null ? void 0 : _b.call(options, value);
      return defaultValue;
    }
  };
  const useFancyParamGet = (paramName, options) => {
    const contextApi = useApi.useContextApi();
    init(contextApi, utils.isClient);
    const { defaultValue } = options;
    const smartDefaultValue = utils.useSmartValue(defaultValue);
    const value = utils.isClient ? reactStore.useStore(paramsStore, (s) => s[paramName]) : getLatestParams(api$1)[paramName];
    const decodedValue = react.useMemo(() => decodeWithDefault(value, smartDefaultValue, options), [value, smartDefaultValue, options]);
    return utils.useSmartValue(decodedValue);
  };
  const useFancyParamSet = (paramName, options) => {
    if (!utils.isClient) {
      throw new Error("Cannot use fancy params on the server");
    }
    const contextApi = useApi.useContextApi();
    init(contextApi, utils.isClient);
    const { defaultValue } = options;
    const smartDefaultValue = utils.useSmartValue(defaultValue);
    return react.useCallback((value, state) => {
      const { updateType = "replaceIn", encode } = options;
      const currentValue = paramsStore.state[paramName];
      const internalValue = typeof value === "function" ? value(decodeWithDefault(currentValue, smartDefaultValue, options)) : value;
      const newValue = encoding.encodeParam(internalValue, encode);
      if (currentValue === newValue || currentValue === void 0 && lodashEs.isEqual(smartDefaultValue, value)) {
        return;
      }
      paramsStore.setState((s) => {
        return { ...s, [paramName]: newValue };
      });
      const search = api$1.getSearch();
      const clearAll = !updateType.endsWith("In");
      const isReplace = updateType.startsWith("replace");
      const searchParams = !clearAll ? new URLSearchParams(search) : new URLSearchParams();
      if (!lodashEs.isEqual(smartDefaultValue, value)) {
        searchParams.set(paramName, newValue);
      } else {
        searchParams.delete(paramName);
      }
      const newHref = `?${searchParams.toString()}`;
      const internalState = { [utils.fancyParamsTransitioning]: true, ...state };
      if (isReplace) {
        api$1.replaceState(newHref, internalState);
      } else {
        api$1.pushState(newHref, internalState);
      }
    }, [paramName, smartDefaultValue, options]);
  };
  const useFancyParam = (paramName, options) => {
    const value = useFancyParamGet(paramName, options);
    const setter = useFancyParamSet(paramName, options);
    return [value, setter];
  };
  return {
    useFancyParamGet,
    useFancyParamSet,
    useFancyParam,
    getInternals: () => {
      return {
        paramsStore,
        api: api$1
      };
    }
  };
};
exports.createFancyParams = createFancyParams;
//# sourceMappingURL=core.cjs.map
