"use strict";
Object.defineProperty(exports, Symbol.toStringTag, { value: "Module" });
const defaultDecoder = JSON.parse;
const defaultEncoder = JSON.stringify;
const stringCoder = {
  encode: (value) => value,
  decode: (value) => value
};
const numberCoder = {
  encode: (value) => value.toString(),
  decode: (value) => parseInt(value)
};
const booleanCoder = {
  encode: (value) => value ? "true" : "false",
  decode: (value) => value === "true"
};
const datetimeCoder = {
  encode: (value) => value.toISOString(),
  decode: (value) => new Date(value)
};
const dateCoder = {
  encode: (value) => value.toISOString().split("T")[0] || "",
  decode: (value) => /* @__PURE__ */ new Date(`${value}T00:00:00Z`)
};
const decodeParam = (param, decoder = defaultDecoder) => {
  return decoder(decodeURIComponent(param));
};
const encodeParam = (param, encoder = defaultEncoder) => {
  return encodeURIComponent(encoder(param));
};
const createListCoder = ({ separator, item }) => {
  return {
    encode: (value) => {
      const builder = item;
      const { encode } = builder.state;
      return value.map((item2) => {
        return encode(item2);
      }).join(separator);
    },
    decode: (value) => {
      const builder = item;
      const { encode } = builder.state;
      return value.split(separator || ",").map((item2) => {
        return encode(item2);
      });
    }
  };
};
exports.booleanCoder = booleanCoder;
exports.createListCoder = createListCoder;
exports.dateCoder = dateCoder;
exports.datetimeCoder = datetimeCoder;
exports.decodeParam = decodeParam;
exports.defaultDecoder = defaultDecoder;
exports.defaultEncoder = defaultEncoder;
exports.encodeParam = encodeParam;
exports.numberCoder = numberCoder;
exports.stringCoder = stringCoder;
//# sourceMappingURL=encoding.cjs.map
