"use strict";
Object.defineProperty(exports, Symbol.toStringTag, { value: "Module" });
const react = require("react");
const utils = require("./utils.cjs");
const createWrappers = ({ useFancyParamGet, useFancyParamSet }) => {
  const useToggleParamSet = (paramName, options) => {
    const setter = useFancyParamSet(paramName, options);
    const toggle = react.useCallback(() => {
      setter((prev) => !prev);
    }, [setter]);
    return {
      toggle
    };
  };
  const useToggleParam = (paramName, options) => {
    const { toggle } = useToggleParamSet(paramName, options);
    const value = useFancyParamGet(paramName, options);
    return {
      toggle,
      value
    };
  };
  const useDialogParamSet = (paramName, options) => {
    const smartDefaultValue = utils.useSmartValue(options.defaultValue);
    const setter = useFancyParamSet(paramName, options);
    const close = react.useCallback(() => {
      setter(smartDefaultValue);
    }, [setter, smartDefaultValue]);
    const open = react.useCallback((state) => {
      setter({
        isOpen: true,
        state
      });
    }, [setter]);
    return {
      close,
      open
    };
  };
  const useDialogParam = (paramName, options) => {
    const value = useFancyParamGet(paramName, options);
    const { open, close } = useDialogParamSet(paramName, options);
    const { isOpen, ...state } = value;
    return {
      isOpen,
      close,
      open,
      state
    };
  };
  return {
    useToggleParamSet,
    useToggleParam,
    useDialogParamSet,
    useDialogParam
  };
};
exports.createWrappers = createWrappers;
//# sourceMappingURL=wrappers.cjs.map
