import { useMemo, useRef } from "react";
import { isEqual } from "lodash-es";
const getRenderingType = () => {
  const isBrowser = typeof window != "undefined" && window.document;
  return isBrowser ? "client" : "server";
};
const isClient = getRenderingType() === "client";
const isServer = getRenderingType() === "server";
const fancyParamsTransitioning = "__fancyParamsTransitioning";
const isFancyTransition = (state) => state != null && typeof state === "object" && fancyParamsTransitioning in state;
const useSmartValue = (value) => {
  const ref = useRef();
  if (ref.current === void 0) {
    ref.current = value;
  }
  if (isEqual(ref.current, value)) {
    return ref.current;
  } else {
    ref.current = value;
    return value;
  }
};
const useMemoOptions = (options, options2, options3) => {
  const smartOptions1 = useSmartValue(options);
  const smartOptions2 = useSmartValue(options2);
  const smartOptions3 = useSmartValue(options3);
  return useMemo(() => mergeOptions(smartOptions1, smartOptions2, smartOptions3), [smartOptions1, smartOptions2, smartOptions3]);
};
const mergeOptions = (...options) => {
  return Object.assign({}, ...options);
};
const camelCaseToKebab = (str) => str.replace(/[A-Z]+(?![a-z])|[A-Z]/g, ($, ofs) => (ofs ? "-" : "") + $.toLowerCase());
export {
  camelCaseToKebab,
  fancyParamsTransitioning,
  getRenderingType,
  isClient,
  isFancyTransition,
  isServer,
  mergeOptions,
  useMemoOptions,
  useSmartValue
};
//# sourceMappingURL=utils.js.map
