import { useCallback } from "react";
import { useSmartValue } from "./utils.js";
const createWrappers = ({ useFancyParamGet, useFancyParamSet }) => {
  const useToggleParamSet = (paramName, options) => {
    const setter = useFancyParamSet(paramName, options);
    const toggle = useCallback(() => {
      setter((prev) => !prev);
    }, [setter]);
    return {
      toggle
    };
  };
  const useToggleParam = (paramName, options) => {
    const { toggle } = useToggleParamSet(paramName, options);
    const value = useFancyParamGet(paramName, options);
    return {
      toggle,
      value
    };
  };
  const useDialogParamSet = (paramName, options) => {
    const smartDefaultValue = useSmartValue(options.defaultValue);
    const setter = useFancyParamSet(paramName, options);
    const close = useCallback(() => {
      setter(smartDefaultValue);
    }, [setter, smartDefaultValue]);
    const open = useCallback((state) => {
      setter({
        isOpen: true,
        state
      });
    }, [setter]);
    return {
      close,
      open
    };
  };
  const useDialogParam = (paramName, options) => {
    const value = useFancyParamGet(paramName, options);
    const { open, close } = useDialogParamSet(paramName, options);
    const { isOpen, ...state } = value;
    return {
      isOpen,
      close,
      open,
      state
    };
  };
  return {
    useToggleParamSet,
    useToggleParam,
    useDialogParamSet,
    useDialogParam
  };
};
export {
  createWrappers
};
//# sourceMappingURL=wrappers.js.map
